
.. _geoclaw_examples_storm_surge_hurricane_isaac:

Basic Example of Storm Surge from Hurricane Isaac
=================================================

This example contains the data and setup for running a storm surge forecast for
Hurricane Isaac.  The example can be run via::

    make all

which should download the necessary topography and storm data, start the 
simulation and plot the results.